#
# spec file for package oniguruma
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_name libonig5
%define short_version 6.9.10
Name:           oniguruma
Version:        6.9.10
Release:        1.3
Summary:        Regex Library Supporting Different Character Encodings
License:        BSD-2-Clause
Group:          Development/Languages/C and C++
URL:            https://github.com/kkos/oniguruma
Source:         https://github.com/kkos/oniguruma/releases/download/v%{version}/onig-%{version}.tar.gz
BuildRequires:  pkgconfig

%description
Oniguruma is a regular expressions library.  The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

%package -n %{lib_name}
Summary:        Regex Library Supporting Different Character Encodings
Group:          System/Libraries

%description -n %{lib_name}
Oniguruma is a regular expressions library.  The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

%package devel
Summary:        Regex Library Supporting Different Character Encodings - Development Files
Group:          Development/Languages/C and C++
Requires:       %{lib_name} = %{version}
Obsoletes:      oniguruma <= 2.5.7

%description devel
Oniguruma is a regular expressions library.  The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

This package contains all necessary include files and libraries needed to
develop applications that require it.

%prep
%setup -q -n onig-%{short_version}
cp -rp sample/ examples

%build
export CFLAGS="%{optflags} -g"
%configure --enable-posix-api
%make_build

%check
cd test
%make_build test

%install
%make_install
find %{buildroot} -type f -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%{_libdir}/libonig.so.*

%files devel
%doc AUTHORS COPYING HISTORY index.html index_ja.html README
%doc doc/* examples/
%{_bindir}/onig-config
%{_includedir}/oniguruma.h
%{_includedir}/oniggnu.h
%{_includedir}/onigposix.h
%{_libdir}/libonig.so
%{_libdir}/pkgconfig/oniguruma.pc

%changelog
* Wed Jan  1 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to 6.9.10
  - Update Unicode version 16.0
  - Add new operator (*SKIP)
  - Fixed: ONIG_SYN_CONTEXT_INDEP_REPEAT_OPS not working for ^*
    pattern (Issue #292)
* Tue Oct 17 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 6.9.9
  - Update Unicode version 15.1.0
  - NEW API: ONIG_OPTION_MATCH_WHOLE_STRING
  - Fixed: (?I) option was not enabled for character classes (Issue
    [#264]).
  - Changed specification to check for incorrect POSIX bracket
    (Issue #253).
  - Changed [[:punct:]] in Unicode encodings to be compatible with
    POSIX definition. (Issue #268)
  - Fixed: ONIG_OPTION_FIND_LONGEST behavior
* Thu May  5 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 6.9.8
  - Update Unicode version 14.0.0
  - Whole options
  - (?C) : ONIG_OPTION_DONT_CAPTURE_GROUP
  - (?I) : ONIG_OPTION_IGNORECASE_IS_ASCII
  - (?L) : ONIG_OPTION_FIND_LONGEST
  - Fixed some problems found by OSS-Fuzz
* Thu Jun  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 6.9.7.1
  * NEW API: ONIG_OPTION_CALLBACK_EACH_MATCH
  * NEW API: ONIG_OPTION_IGNORECASE_IS_ASCII
  * NEW API: ONIG_SYNTAX_PYTHON
  * Fixed some problems found by OSS-Fuzz
- Enable tests
* Thu Nov  5 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 6.9.6
  - When using configure script, if you have the POSIX API enabled
    in an earlier version (disabled by default in 6.9.5) and you
    need application binary compatibility with the POSIX API,
    specify "--enable-binary-compatible-posix-api=yes" instead of
    "--enable-posix-api=yes". Starting in 6.9.6,
    "--enable-posix-api=yes" only supports source-level
    compatibility for 6.9.5 and earlier about POSIX API. (Issue
    [#210])
  - NEW: configure option
  - -enable-binary-compatible-posix-api=[yes/no]
  - NEW API: Limiting the maximum number of calls of subexp-call
  - NEW API: ONIG_OPTION_NOT_BEGIN_STRING / NOT_END_STRING /
    NOT_BEGIN_POSITION
  - Fixed behavior of ONIG_OPTION_NOTBOL / NOTEOL
  - Fixed many problems found by OSS-Fuzz
  - Fixed many problems found by Coverity
  - Fixed CVE-2020-26159 (This turned out not to be a problem
    later. #221)
  - Under cygwin and mingw, generate and install the libonig.def
    file (Issue #220)
* Mon Jun 15 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 6.9.5.1
  - Fixed Issue #192
  - POSIX API disabled by default for Unix (* Enabled by: configure
  - -enable-posix-api=yes)
  - Update Unicode version 13.0.0
  - NEW: Code point sequence notation \x{HHHH HHHH ...}, \o{OOOO
    OOOO ...}
  - NEW API: retry limit in search functions
  - NEW API: maximum nesting level of subexp call
  - Fixed behavior of isolated options in Perl and Java syntaxes.
    /...(?i).../
  - fix a problem (found by oss-fuzz test on my PC)
- add --enable-posix-api to keep the posix API enabled.
* Wed Mar  4 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 6.9.4
  - NEW API: RegSet (set of regexes)
  - Fixed CVE-2019-19012 (boo# 1156984)
  - Fixed CVE-2019-19203 (boo# 1164550) (Does not affect UTF-8,
    UTF-16 and UTF-32 encodings)
  - Fixed CVE-2019-19204 (boo# 1164569) (Affects only PosixBasic,
    Emacs and Grep syntaxes)
  - Fixed CVE-2019-19246 (boo# 1157805)
  - Fixed some problems (found by libFuzzer test)
- changes from 6.9.3
  - Fixed CVE-2019-13224 (boo# 1142847)
  - Fixed CVE-2019-13225 (boo# 1141157)
  - Fixed many problems (found by libfuzzer programs)
- changes from 6.9.2
  - Update Unicode version 12.1.0
  - NEW: Unicode Text Segment mode option (?y{g}) (?y{w}) g:
    Extended Grapheme Cluster mode / w: Word mode
  - Fix Issue #139
- changes from 6.9.1
  - Speed improvement (* especially UTF-8)
- changes from 6.9.0
  - Update Unicode version 11.0.0
  - NEW: add Emoji properties
- changes from 6.8.2
  - Fix: #80 UChar in header causes issue
  - NEW API: onig_set_callout_user_data_of_match_param() (*
    omission in 6.8.0)
  - add doc/CALLOUTS.API and doc/CALLOUTS.API.ja
- changes from 6.8.1
  - Update shared library version to 5.0.0 for API incompatible
    changes from 6.7.1
- changes from 6.8.0
  - Retry-limit-in-match function enabled by default
  - NEW: configure option --enable-posix-api=no (* enabled by
    default)
  - NEW API: onig_search_with_param(), onig_match_with_param()
  - NEW: Callouts of contents (?{...contents...}) (?{...}[X<>])
    (?{{....}})
  - NEW: Callouts of name (*name) (*name[tag]{args...})
  - NEW: Builtin callouts (*FAIL) (*MISMATCH) (*ERROR{n}) (*COUNT)
    (*MAX{n}) etc..
  - (* Callout function API is experimental level and isn't fixed
    definitely yet. Undocumented now)
- changes from 6.7.1
  - NEW: Mechanism of try-in-match-limit (* disabled by default)
  - #73: Update for automake 1.15.1
* Sat Dec 23 2017 avindra@opensuse.org
- Version 6.7.0
  - add ONIG_SYNTAX_ONIGURUMA (default syntax)
  - restructure StackType
  - implement subexp calls (?R), (?&name), (?-n), (?+n) for Perl
    syntax
  - use string pool of gperf for Unicode Property lookup function
  - fix an empty greedy regex and a word boundary (.*\b) fails
  - remove a stack type STK_POS
  - add a declaration of onig_end()
  - fix compilation failure in out-of-source build
  - [new] hexadecimal codepoint \uHHHH
- Version 6.6.1
  - fix definition of \X to (?>\O(?:\Y\O)*)
- Version 6.6.0
  - rename Absent clear to Range clear
  - [new] Extended Grapheme Cluster \X and boundary \y, \Y
  - fix: invalid index(ctype) value assigned to Unicode Block
    properties
  - --enable-crnl-as-line-terminator to be deprecated
  - [new] ASCII only mode options (?WDSP)
  - [new] ONIG_OPTION_XXXX_IS_ASCII  options
  - disable OP_CCLASS_NODE
  - [spec] Absent clear restore previous range value at backtrack
  - optimize for simple one char repetition in Absent expression
  - fix: invalid impl. for reluctant repetition in Absent expression
  - remove compile switch USE_NAMED_GROUP
  - Visual Studio 2005 compilation fixed
- cleanup with spec-cleaner
* Mon Aug  7 2017 mrueckert@suse.de
- Version 6.5.0
  - [new] support Absent clear (Absent functions)
  - abolish configure option: --enable-combination-explosion-check
  - [new] support Absent functions (?~...)
  - fix #65: SIZEOF_SIZE_T doesn't exist on certain architecutres
  - [new] support \O (true anychar)
  - [new] support \K (keep)
  - add new node type: NODE_GIMMICK
  - [new] support \N (no newline)
  - [new] support \R (general newline)
  - [new] support if-then-else syntax
  - [new] support backref validity checker
- Version 6.4.0
  - fix memory leaks
  - change encoding of doc/XXXX.ja from EUC-JP to UTF-8
  - update doc/RE, and doc/RE.ja
  - fix fatal bug of endless repeat check on Windows
  - PR #62 : add check for return values
  - [new] support call zero (\g{0})
  - [new] support relative call by positive number
  - [new] support relative back-reference by positive number
  - fix #60 : check value type
  - change output format for ONIG_DEBUG_COMPILE and
    ONIG_DEBUG_MATCH
- Version 6.3.0
  - fix #60 : invalid state(CCS_VALUE) in parse_char_class()
  - fix #59 : access to invalid address by reg->dmax value
  - fix invalid increment of start position in onig_scan()
  - fix #58 : access to invalid address by reg->dmin value
  - fix #57 : DATA_ENSURE() check must be before data access
  - fix #56 : return invalid result for codepoint 0xFFFFFFFF
  - [new] add \o{17777777777} syntax.
  - fix #55 : Byte value expressed in octal must be smaller than
    256
- Version 6.2.0
  - fix: size in xmemcpy in stack_double (PR #51)
  - Initialize return value
  - NEW API: add onig_set_capture_num_limit()
  - change MemNumType from short int to int
  - fix: [0-9-a] was not allowed as [0-9\-a]
  - fix: illegal capture after recursive call
  - fix: problem with optimization of \z
  - fix: .* optimization
  - Set a limit of parser recursion
  - fix; that warnings are not shown properly
  - fix: /[a-c#]+\W/ =~ "def#" fails when encoding is UTF-16/32
  - fix: /[\x{0}-X]/i doesn't match properly when UTF-16/32 is
    used.
- Version 6.1.3
  - fix: Syntax error: redirection unexpected (expecting word) #35
- Version 6.1.2
  - allow word bound, word begin and word end in look-behind.
  - add ONIG_OPTION_CHECK_VALIDITY_OF_STRING option.
  - fix use after free node.
  - fix memory leaks after parsing regexp error.
  - implement many of is_valid_mbc_string().
- Version 6.1.1
  - fix segfault /W.?{888}{888}{888}\x00/ (found by libfuzzer)
  - fix error unmatched close parenthesis for %%{(.*?)} #23
- Version 6.1.0
  - add contributed/libfuzzer-onig.cpp  (thanks hannob)
  - update LTVERSION 4:0:0
  - NEW API: onigenc_is_valid_mbc_string().
  - add is_valid_mbc_string() member into OnigEncodingType.
  - fix out of bounds read.
  - disable USE_INVALID_CODE_SCHEME.
  - doc/RE improved.
  - add onig_scan() into doc/API.
  - fix bug: Out of bounds read in onig_strcpy() #17
  - fix bug: infinite loop of backreference and group.
  - fix out of bounds read in mbc_to_code() #16
  - doc/RE refinements.
  - add onig_scan() (NEW API)
  - reimplement match stack allocation for case too many repeat
  - and too many captures in regexp.
  - number of captures <= 32767 for bytecode representation.
  - don't use int_map_backward for thread-safe.
  - fix case of enclosed option in look-behind.
  - fix ignore case in look-behind.
  - fix memory leak in onig_unicode_define_user_property()
  - declare variables at the top of scope.  (thanks nmaya)
- Version 6.0.0
  - add NEW API: onig_unicode_define_user_property()
  - update Unicode data to 8.0.0
  - change OnigCodePoint type to unsigned int.
  - add doc/UNICODE_PROPERTIES.
  - add error code ONIGERR_FAIL_TO_INITIALIZE.
  - add make_win64/32.bat.
  - fix bug of uninitialized regex_t value on error.
  - reimplement Unicode case folding.
  - update LTVERSION = 3.0.0
  - remove all THREAD_ macro.
  - add init member into OnigEncoding. (add onig_initialize())
  - remove state member of regex.
  - move source files into src/
  - rename configre.in to configure.ac.
  - fix memory leak. (thanks pigzang)
  - change mail address.
* Tue Mar  1 2016 mrueckert@suse.de
- remove ruby build requires. seems unused.
* Wed Oct 21 2015 i@marguerite.su
- update version 5.9.6
  * [impl] add onigenc_end_unicode().
  * [impl] add onig_add_end_call().
* Sat Sep  6 2014 i@marguerite.su
- update version 5.9.5
  * [impl] escape warnings for -Wall.
  * [impl] remove unused variable.
- changes in 5.9.4
  * [dist] add oniguruma.pc.in file
- changes in 5.9.3
  * fix print_tree ENCLOSE_OPTION bug
* Sat Aug 14 2010 gber@opensuse.org
- update to version 5.9.2:
  + many fixes
- cleanup:
  + split into liborig2 and oniguruma-devel subpackages
  + corrected license information
  + changed summary to conform with policy
* Fri Sep 29 2006 mrueckert@suse.de
- update to version 2.5.7:
  many fixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 27 2005 mrueckert@suse.de
- Initial package of version 2.5.1
